@@ -1,6 +1,6 @@
 """
-LEGION (https://govanguard.com)
-Copyright (c) 2022 GoVanguard
+LEGION (https://gotham-security.com)
+Copyright (c) 2023 Gotham Security
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,11 +13,11 @@ Copyright (c) 2022 GoVanguard
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 import sys
 
-from PyQt5 import QtCore
+from PyQt6 import QtCore
 
 from app.actions.updateProgress import AbstractUpdateProgressObservable
 from app.logging.legionLog import getAppLogger
@@ -73,7 +73,7 @@ class NmapImporter(QtCore.QThread):
                 nmapReport = parseNmapReport(self.filename)
             except MalformedXmlDocumentException as e:
                 self.tsLog('Giving up on import due to previous errors.')
-                appLog.error(f"nmap xml report is likely malformed: {e}")
+                appLog.error(f"NMAP xml report is likely malformed: {e}")
                 self.updateProgressObservable.finished()
                 self.done.emit()
                 return
@@ -85,18 +85,20 @@ class NmapImporter(QtCore.QThread):
                 n = nmapSessionObj(self.filename, s.startTime, s.finish_time, s.nmapVersion, s.scanArgs, s.totalHosts,
                                    s.upHosts, s.downHosts)
                 session.add(n)
+                session.commit()
 
             allHosts = nmapReport.getAllHosts()
             hostCount = len(allHosts)
             if hostCount == 0:  # to fix a division by zero if we ran nmap on one host
                 hostCount = 1
-            totalprogress = 0
-
-            self.updateProgressObservable.updateProgress(totalprogress)
 
             createProgress = 0
             createOsNodesProgress = 0
             createPortsProgress = 0
+            createDbScriptsProgress = 0
+            updateObjectsRunScriptsProgress = 0
+
+            self.updateProgressObservable.updateProgress(int(createProgress), 'Adding hosts...')
 
             for h in allHosts:  # create all the hosts that need to be created
                 db_host = self.hostRepository.getHostInformation(h.ip)
@@ -107,16 +109,17 @@ class NmapImporter(QtCore.QThread):
                                   lastboot=h.lastboot, distance=h.distance, state=h.state, count=h.count)
                     self.tsLog("Adding db_host")
                     session.add(hid)
+                    session.commit()
                     t_note = note(h.ip, 'Added by nmap')
                     session.add(t_note)
+                    session.commit()
                 else:
                     self.tsLog("Found db_host already in db")
 
-                createProgress = createProgress + ((100.0 / hostCount) / 5)
-                totalprogress = totalprogress + createProgress
-                self.updateProgressObservable.updateProgress(int(totalprogress))
+                createProgress = createProgress + (100.0 / hostCount)
+                self.updateProgressObservable.updateProgress(int(createProgress), 'Adding hosts...')
 
-            session.commit()
+            self.updateProgressObservable.updateProgress(int(createOsNodesProgress), 'Creating Service, Port and OS children...')
 
             for h in allHosts:  # create all OS, service and port objects that need to be created
                 self.tsLog("Processing h {ip}".format(ip=h.ip))
@@ -125,7 +128,10 @@ class NmapImporter(QtCore.QThread):
                 if db_host:
                     self.tsLog("Found db_host during os/ports/service processing")
                 else:
-                    self.log("Did not find db_host during os/ports/service processing")
+                    self.tsLog("Did not find db_host during os/ports/service processing")
+                    self.tsLog("A host that should have been found was not. Something is wrong. Save your session and report a bug.")
+                    self.tsLog("Include your nmap file, sanitized if needed.")
+                    continue
 
                 os_nodes = h.getOs()  # parse and store all the OS nodes
                 self.tsLog("    'os_nodes' to process: {os_nodes}".format(os_nodes=str(len(os_nodes))))
@@ -139,31 +145,33 @@ class NmapImporter(QtCore.QThread):
                         t_osObj = osObj(os.name, os.family, os.generation, os.osType, os.vendor, os.accuracy,
                             db_host.id)
                         session.add(t_osObj)
+                        session.commit()
 
-                    createOsNodesProgress = createOsNodesProgress + ((100.0 / hostCount) / 5)
-                    totalprogress = totalprogress + createOsNodesProgress
-                    self.updateProgressObservable.updateProgress(int(totalprogress))
+                createOsNodesProgress = createOsNodesProgress + (100.0 / hostCount)
+                self.updateProgressObservable.updateProgress(int(createOsNodesProgress), 'Creating Service, Port and OS children...')
 
-                session.commit()
+                self.updateProgressObservable.updateProgress(int(createPortsProgress), 'Processing ports...')
 
                 all_ports = h.all_ports()
+                portCount = len(all_ports)
                 self.tsLog("    'ports' to process: {all_ports}".format(all_ports=str(len(all_ports))))
                 for p in all_ports:  # parse the ports
                     self.tsLog("        Processing port obj {port}".format(port=str(p.portId)))
                     s = p.getService()
 
                     if not (s is None):  # check if service already exists to avoid adding duplicates
-                        print("Processing service result *********** name={0} prod={1} ver={2} extra={3} fing={4}"
+                        self.tsLog("            Processing service result *********** name={0} prod={1} ver={2} extra={3} fing={4}"
                             .format(s.name, s.product, s.version, s.extrainfo, s.fingerprint))
                         db_service = session.query(serviceObj).filter_by(hostId=db_host.id) \
                             .filter_by(name=s.name).filter_by(product=s.product).filter_by(version=s.version) \
                             .filter_by(extrainfo=s.extrainfo).filter_by(fingerprint=s.fingerprint).first()
                         if not db_service:
-                            print("Did not find service *********** name={0} prod={1} ver={2} extra={3} fing={4}"
+                            self.tsLog("            Did not find service *********** name={0} prod={1} ver={2} extra={3} fing={4}"
                                 .format(s.name, s.product, s.version, s.extrainfo, s.fingerprint))
                             db_service = serviceObj(s.name, db_host.id, s.product, s.version, s.extrainfo,
                                 s.fingerprint)
                             session.add(db_service)
+                            session.commit()
                     else:  # else, there is no service info to parse
                         db_service = None
                         # fetch the port
@@ -171,22 +179,17 @@ class NmapImporter(QtCore.QThread):
                         .filter_by(protocol=p.protocol).first()
 
                     if not db_port:
-                        # print("Did not find port *********** portid={0} proto={1}".format(p.portId, p.protocol))
+                        self.tsLog("            Did not find port *********** portid={0} proto={1}".format(p.portId, p.protocol))
                         if db_service:
                             db_port = portObj(p.portId, p.protocol, p.state, db_host.id, db_service.id)
                         else:
                             db_port = portObj(p.portId, p.protocol, p.state, db_host.id, '')
                         session.add(db_port)
-                    # else:
-                    # print('FOUND port *************** portid={0}'.format(db_port.portId))
-                    createPortsProgress = createPortsProgress + ((100.0 / hostCount) / 5)
-                    totalprogress = totalprogress + createPortsProgress
-                    self.updateProgressObservable.updateProgress(totalprogress)
+                        session.commit()
+                createPortsProgress = createPortsProgress + (100.0 / hostCount)
+                self.updateProgressObservable.updateProgress(createPortsProgress, 'Processing ports...')
 
-            session.commit()
-
-            # totalprogress += progress
-            # self.tick.emit(int(totalprogress))
+            self.updateProgressObservable.updateProgress(createDbScriptsProgress, 'Creating script objects...')
 
             for h in allHosts:  # create all script objects that need to be created
                 db_host = self.hostRepository.getHostInformation(h.ip)
@@ -194,11 +197,12 @@ class NmapImporter(QtCore.QThread):
                 for p in h.all_ports():
                     for scr in p.getScripts():
                         self.tsLog("        Processing script obj {scr}".format(scr=str(scr)))
-                        print("        Processing script obj {scr}".format(scr=str(scr)))
                         db_port = session.query(portObj).filter_by(hostId=db_host.id) \
                             .filter_by(portId=p.portId).filter_by(protocol=p.protocol).first()
-                        #db_script = session.query(l1ScriptObj).filter_by(scriptId=scr.scriptId) \
-                        #   .filter_by(portId=db_port.id).first()
+                        # Todo
+                        db_script = session.query(l1ScriptObj).filter_by(scriptId=scr.scriptId) \
+                            .filter_by(portId=db_port.id).first()
+                        # end todo
                         db_script = session.query(l1ScriptObj).filter_by(hostId=db_host.id) \
                            .filter_by(portId=db_port.id).first()
 
@@ -206,19 +210,26 @@ class NmapImporter(QtCore.QThread):
                             t_l1ScriptObj = l1ScriptObj(scr.scriptId, scr.output, db_port.id, db_host.id)
                             self.tsLog("        Adding l1ScriptObj obj {script}".format(script=scr.scriptId))
                             session.add(t_l1ScriptObj)
-
+                            session.commit()
                 for hs in h.getHostScripts():
                     db_script = session.query(l1ScriptObj).filter_by(scriptId=hs.scriptId) \
                         .filter_by(hostId=db_host.id).first()
                     if not db_script:
                         t_l1ScriptObj = l1ScriptObj(hs.scriptId, hs.output, None, db_host.id)
                         session.add(t_l1ScriptObj)
+                        session.commit()
 
-            session.commit()
+                createDbScriptsProgress = createDbScriptsProgress + (100.0 / hostCount)
+                self.updateProgressObservable.updateProgress(createDbScriptsProgress, 'Creating script objects...')
+
+            self.updateProgressObservable.updateProgress(updateObjectsRunScriptsProgress, 'Update objects and run scripts...')
 
             for h in allHosts:  # update everything
 
                 db_host = self.hostRepository.getHostInformation(h.ip)
+                if not db_host:
+                    self.tsLog("            A host that should have been found was not. Something is wrong. Save your session and report a bug.")
+                    self.tsLog("            Include your nmap file, sanitized if needed.")
 
                 if db_host.ipv4 == '' and not h.ipv4 == '':
                     db_host.ipv4 = h.ipv4
@@ -244,6 +255,7 @@ class NmapImporter(QtCore.QThread):
                     db_host.count = h.count
 
                 session.add(db_host)
+                session.commit()
 
                 tmp_name = ''
                 tmp_accuracy = '0'  # TODO: check if better to convert to int for comparison
@@ -269,20 +281,23 @@ class NmapImporter(QtCore.QThread):
                         db_host.osAccuracy = tmp_accuracy
 
                 session.add(db_host)
+                session.commit()
 
                 for scr in h.getHostScripts():
-                    print("-----------------------Host SCR: {0}".format(scr.scriptId))
+                    self.tsLog("-----------------------Host SCR: {0}".format(scr.scriptId))
                     db_host = self.hostRepository.getHostInformation(h.ip)
                     scrProcessorResults = scr.scriptSelector(db_host)
                     for scrProcessorResult in scrProcessorResults:
                         session.add(scrProcessorResult)
+                        session.commit()
 
                 for scr in h.getScripts():
-                    print("-----------------------SCR: {0}".format(scr.scriptId))
+                    self.tsLog("-----------------------SCR: {0}".format(scr.scriptId))
                     db_host = self.hostRepository.getHostInformation(h.ip)
                     scrProcessorResults = scr.scriptSelector(db_host)
                     for scrProcessorResult in scrProcessorResults:
                         session.add(scrProcessorResult)
+                        session.commit()
 
                 for p in h.all_ports():
                     s = p.getService()
@@ -291,25 +306,21 @@ class NmapImporter(QtCore.QThread):
                             .filter_by(name=s.name).filter_by(product=s.product) \
                             .filter_by(version=s.version).filter_by(extrainfo=s.extrainfo) \
                             .filter_by(fingerprint=s.fingerprint).first()
-                        #db_service = session.query(serviceObj).filter_by(hostId=db_host.id) \
-                        #    .filter_by(name=s.name).first()
                     else:
                         db_service = None
                         # fetch the port
                     db_port = session.query(portObj).filter_by(hostId=db_host.id).filter_by(portId=p.portId) \
                         .filter_by(protocol=p.protocol).first()
                     if db_port:
-                        # print("************************ Found {0}".format(db_port))
-
                         if db_port.state != p.state:
                             db_port.state = p.state
                             session.add(db_port)
-
+                            session.commit()
                         # if there is some new service information, update it -- might be causing issue 164
                         if not (db_service is None) and db_port.serviceId != db_service.id:
                             db_port.serviceId = db_service.id
                             session.add(db_port)
-
+                            session.commit()
                     # store the script results (note that existing script outputs are also kept)
                     for scr in p.getScripts():
                         db_script = session.query(l1ScriptObj).filter_by(scriptId=scr.scriptId) \
@@ -319,8 +330,12 @@ class NmapImporter(QtCore.QThread):
                             db_script.output = scr.output
 
                         session.add(db_script)
+                        session.commit()
 
-            self.updateProgressObservable.updateProgress(100)
+                updateObjectsRunScriptsProgress = updateObjectsRunScriptsProgress + (100.0 / hostCount)
+                self.updateProgressObservable.updateProgress(updateObjectsRunScriptsProgress, 'Update objects and run scripts...')
+
+            self.updateProgressObservable.updateProgress(100, 'Almost done...')
 
             session.commit()
             self.db.dbsemaphore.release()  # we are done with the DB
