@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
-LEGION (https://govanguard.com)
-Copyright (c) 2022 GoVanguard
+LEGION (https://gotham-security.com)
+Copyright (c) 2023 Gotham Security
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -25,6 +25,7 @@ from app.actions.updateProgress.UpdateProgressObservable import UpdateProgressOb
 from app.importers.NmapImporter import NmapImporter
 from app.importers.PythonImporter import PythonImporter
 from app.tools.nmap.NmapPaths import getNmapRunningFolder
+from app.auxiliary import unixPath2Win, winPath2Unix, getPid, formatCommandQProcess, isWsl
 from ui.observers.QtUpdateProgressObserver import QtUpdateProgressObserver
 
 try:
@@ -79,12 +80,18 @@ class Controller:
         self.nmapImporter = NmapImporter(updateProgressObservable,
                                          self.logic.activeProject.repositoryContainer.hostRepository)
         self.nmapImporter.done.connect(self.importFinished)
+        self.nmapImporter.done.connect(self.view.updateInterface)
+        self.nmapImporter.done.connect(self.view.updateToolsTableView)
+        self.nmapImporter.done.connect(self.view.updateProcessesTableView)
         self.nmapImporter.schedule.connect(self.scheduler)              # run automated attacks
         self.nmapImporter.log.connect(self.view.ui.LogOutputTextView.append)
 
     def initPythonImporter(self):
         self.pythonImporter = PythonImporter()
         self.pythonImporter.done.connect(self.importFinished)
+        self.pythonImporter.done.connect(self.view.updateInterface)
+        self.pythonImporter.done.connect(self.view.updateToolsTableView)
+        self.pythonImporter.done.connect(self.view.updateProcessesTableView)
         self.pythonImporter.schedule.connect(self.scheduler)              # run automated attacks
         self.pythonImporter.log.connect(self.view.ui.LogOutputTextView.append)
 
@@ -103,17 +110,19 @@ class Controller:
     def initTimers(self):
         self.updateUITimer = QTimer()
         self.updateUITimer.setSingleShot(True)
-        self.updateUITimer.timeout.connect(self.view.updateProcessesTableView)
-        self.updateUITimer.timeout.connect(self.view.updateToolsTableView)
+        # Moving to deprecate all these general interface update timers
+        #self.updateUITimer.timeout.connect(self.view.updateProcessesTableView)
+        #self.updateUITimer.timeout.connect(self.view.updateToolsTableView)
 
         self.updateUI2Timer = QTimer()
         self.updateUI2Timer.setSingleShot(True)
-        self.updateUI2Timer.timeout.connect(self.view.updateInterface)
+        # Moving to deprecate all these general interface update timers
+        #self.updateUI2Timer.timeout.connect(self.view.updateInterface)
 
         self.processTableUiUpdateTimer = QTimer()
         self.processTableUiUpdateTimer.timeout.connect(self.view.updateProcessesTableView)
         # Update only when queue > 0
-        self.processTableUiUpdateTimer.start(1000) # Faster than this doesn't make anything smoother
+        self.processTableUiUpdateTimer.start(500) # Faster than this doesn't make anything smoother
 
     # this function fetches all the settings from the conf file. Among other things it populates the actions lists
     # that will be used in the context menus.
@@ -227,6 +236,10 @@ class Controller:
         self.view.updateProcessesTableView()                            # clear process table
         self.logic.projectManager.closeProject(self.logic.activeProject)
 
+    def copyToClipboard(self, data):
+        clipboard = QtWidgets.QApplication.clipboard()
+        clipboard.setText(data)  # Assuming item.text() contains the IP or hostname
+
     @timing
     def addHosts(self, targetHosts, runHostDiscovery, runStagedNmap, nmapSpeed, scanMode, nmapOptions = []):
         if targetHosts == '':
@@ -239,18 +252,23 @@ class Controller:
                 self.runStagedNmap(targetHosts, runHostDiscovery)
             elif runHostDiscovery:
                 outputfile = getNmapRunningFolder(runningFolder) + "/" + getTimestamp() + '-host-discover'
+                if isWsl():
+                    outputfile = unixPath2Win(outputfile)
                 command = f"nmap -n -sV -O --version-light -T{str(nmapSpeed)} {targetHosts} -oA {outputfile}"
-                log.info("Running {command}".format(command=command))
                 self.runCommand('nmap', 'nmap (discovery)', targetHosts, '', '', command, getTimestamp(True),
                                 outputfile, self.view.createNewTabForHost(str(targetHosts), 'nmap (discovery)', True))
             else:
                 outputfile = getNmapRunningFolder(runningFolder) + "/" + getTimestamp() + '-nmap-list'
+                if isWsl():
+                    outputfile = unixPath2Win(outputfile)
                 command = "nmap -n -sL -T" + str(nmapSpeed) + " " + targetHosts + " -oA " + outputfile
                 self.runCommand('nmap', 'nmap (list)', targetHosts, '', '', command, getTimestamp(True),
                                 outputfile,
                                 self.view.createNewTabForHost(str(targetHosts), 'nmap (list)', True))
         elif scanMode == 'Hard':
             outputfile = getNmapRunningFolder(runningFolder) + "/" + getTimestamp() + '-nmap-custom'
+            if isWsl():
+                outputfile = unixPath2Win(outputfile)
             nmapOptionsString = ' '.join(nmapOptions)
             if 'randomize' not in nmapOptionsString:
                 nmapOptionsString = nmapOptionsString + " -T" + str(nmapSpeed)
@@ -352,6 +370,11 @@ class Controller:
                              re.sub("[^0-9a-zA-Z]", "", str(self.settings.hostActions[i][1])) + "-" + ip
                 command = str(self.settings.hostActions[i][2])
                 command = command.replace('[IP]', ip).replace('[OUTPUT]', outputfile)
+                if 'nmap' in command:
+                    if isWsl():
+                        command = "{0} -oA {1}".format(command, unixPath2Win(outputfile))
+                    else:
+                        command = "{0} -oA {1}".format(command, outputfile)
 
                 # check if same type of nmap scan has already been made and purge results before scanning
                 if 'nmap' in command:
@@ -385,7 +408,7 @@ class Controller:
 
         # if the user pressed SHIFT+Right-click show full menu
         modifiers = QtWidgets.QApplication.keyboardModifiers()
-        if modifiers == QtCore.Qt.ShiftModifier:
+        if modifiers == QtCore.Qt.KeyboardModifier.ShiftModifier:
             shiftPressed = True
         else:
             shiftPressed = False
@@ -398,7 +421,7 @@ class Controller:
         if action.text() == 'Take screenshot':
             for ip in targets:
                 url = ip[0] + ':' + ip[1]
-                self.screenshooter.addToQueue(url)
+                self.screenshooter.addToQueue(ip[0], ip[1], url)
             self.screenshooter.start()
             return
 
@@ -421,6 +444,11 @@ class Controller:
 
                     command = str(self.settings.portActions[srvc_num][2])
                     command = command.replace('[IP]', ip[0]).replace('[PORT]', ip[1]).replace('[OUTPUT]', outputfile)
+                    if 'nmap' in command:
+                        if isWsl():
+                            command = "{0} -oA {1}".format(command, unixPath2Win(outputfile))
+                        else:
+                            command = "{0} -oA {1}".format(command, outputfile)
 
                     if 'nmap' in command and ip[2] == 'udp':
                         command = command.replace("-sV", "-sVU")
@@ -440,7 +468,7 @@ class Controller:
         menu = QMenu()
 
         modifiers = QtWidgets.QApplication.keyboardModifiers()  # if the user pressed SHIFT+Right-click show full menu
-        if modifiers == QtCore.Qt.ShiftModifier:
+        if modifiers == QtCore.Qt.KeyboardModifier.ShiftModifier:
             serviceName='*'
 
         terminalActions = []  # custom terminal actions from settings file
@@ -583,9 +611,9 @@ class Controller:
     #################### PROCESSES ####################
 
     def checkProcessQueue(self):
-        log.debug('# MAX PROCESSES: ' + str(self.settings.general_max_fast_processes))
-        log.debug('# Fast processes running: ' + str(self.fastProcessesRunning))
-        log.debug('# Fast processes queued: ' + str(self.fastProcessQueue.qsize()))
+        log.debug('Queue maximum concurrent processes: {0}'.format(str(self.settings.general_max_fast_processes)))
+        log.debug('Queue processes running: {0}'.format(str(self.fastProcessesRunning)))
+        log.debug('Queue processes waiting: {0}'.format(str(self.fastProcessQueue.qsize())))
 
         if not self.fastProcessQueue.empty():
             self.processTableUiUpdateTimer.start(1000)
@@ -593,21 +621,23 @@ class Controller:
                 next_proc = self.fastProcessQueue.get()
                 if not self.logic.activeProject.repositoryContainer.processRepository.isCancelledProcess(
                         str(next_proc.id)):
-                    log.debug('Running: ' + str(next_proc.command))
+                    log.info('Running: ' + str(next_proc.command))
                     next_proc.display.clear()
                     self.processes.append(next_proc)
                     self.fastProcessesRunning += 1
                     # Add Timeout
                     next_proc.waitForFinished(10)
-                    next_proc.start(next_proc.command)
+                    formattedCommand = formatCommandQProcess(next_proc.command)
+                    log.debug('Up next: {0}, {1}'.format(formattedCommand[0], formattedCommand[1]))
+                    next_proc.start(formattedCommand[0], formattedCommand[1])
                     self.logic.activeProject.repositoryContainer.processRepository.storeProcessRunningStatus(
-                        next_proc.id, next_proc.pid())
+                        next_proc.id, getPid(next_proc))
                 elif not self.fastProcessQueue.empty():
-                    log.debug('> next process was canceled, checking queue again..')
+                    log.debug('Process was canceled, checking queue again..')
                     self.checkProcessQueue()
-        #else:
-        #    log.info("Halting process panel update timer as all processes are finished.")
-        #    self.processTableUiUpdateTimer.stop()
+        else:
+            log.info("Halting process panel update timer as all processes are finished.")
+            self.processTableUiUpdateTimer.stop()
 
     def cancelProcess(self, dbId):
         log.info('Canceling process: ' + str(dbId))
@@ -630,7 +660,7 @@ class Controller:
         log.info('Killing running processes!')
         for p in self.processes:
             p.finished.disconnect()                 # experimental
-            self.killProcess(int(p.pid()), p.id)
+            self.killProcess(int(getPid(p)), p.id)
 
     # this function creates a new process, runs the command and takes care of displaying the ouput. returns the PID
     # the last 3 parameters are only used when the command is a staged nmap
@@ -645,7 +675,7 @@ class Controller:
 
         def handleProcUpdate(*vargs):
             procTime = timer.elapsed() / 1000
-            self.processMeasurements[qProcess.pid()] = procTime
+            self.processMeasurements[getPid(qProcess)] = procTime
 
         name = args[0]
         tabTitle = args[1]
@@ -656,7 +686,7 @@ class Controller:
         startTime = args[6]
         outputfile = args[7]
         textbox = args[8]
-        timer = QtCore.QTime()
+        timer = QElapsedTimer()
         updateElapsed = QTimer()
 
         self.logic.createFolderForTool(name)
@@ -669,7 +699,7 @@ class Controller:
         textbox.setProperty('dbId', str(processRepository.storeProcess(qProcess)))
         updateElapsed.start(1000)
         self.processTimers[qProcess.id] = updateElapsed
-        self.processMeasurements[qProcess.pid()] = 0
+        self.processMeasurements[getPid(qProcess)] = 0
 
         log.info('Queuing: ' + str(command))
         self.fastProcessQueue.put(qProcess)
@@ -681,13 +711,16 @@ class Controller:
         # while the process is running, when there's output to read, display it in the GUI
         self.updateUITimer.start(900)
 
-        qProcess.setProcessChannelMode(QtCore.QProcess.MergedChannels)
+        qProcess.setProcessChannelMode(QtCore.QProcess.ProcessChannelMode.MergedChannels)
         qProcess.readyReadStandardOutput.connect(lambda: qProcess.display.appendPlainText(
             str(qProcess.readAllStandardOutput().data().decode('ISO-8859-1'))))
 
+        #qProcess.readyReadStandardError.connect(lambda: qProcess.display.appendPlainText(
+        #    str(qProcess.readAllStandardError().data().decode('ISO-8859-1'))))
+
         qProcess.sigHydra.connect(self.handleHydraFindings)
         qProcess.finished.connect(lambda: self.processFinished(qProcess))
-        qProcess.error.connect(lambda: self.processCrashed(qProcess))
+        qProcess.errorOccurred.connect(lambda: self.processCrashed(qProcess))
         log.info("runCommand called for stage {0}".format(str(stage)))
 
         if stage > 0 and stage < 6:  # if this is a staged nmap, launch the next stage
@@ -697,7 +730,7 @@ class Controller:
                 lambda: self.runStagedNmap(str(hostIp), discovery=discovery, stage=nextStage,
                                            stop=processRepository.isKilledProcess(str(qProcess.id))))
 
-        return qProcess.pid()  # return the pid so that we can kill the process if needed
+        return getPid(qProcess)  # return the pid so that we can kill the process if needed
 
     def runPython(self):
         textbox = self.view.createNewConsole("python")
@@ -725,7 +758,7 @@ class Controller:
         self.updateUITimer.stop()   # update the processes table
         self.updateUITimer.start(900)
 
-        qProcess.setProcessChannelMode(QtCore.QProcess.MergedChannels)
+        qProcess.setProcessChannelMode(QtCore.QProcess.ProcessChannelMode.MergedChannels)
         qProcess.readyReadStandardOutput.connect(lambda: qProcess.display.appendPlainText(
             str(qProcess.readAllStandardOutput().data().decode('ISO-8859-1'))))
 
@@ -733,7 +766,7 @@ class Controller:
         qProcess.finished.connect(lambda: self.processFinished(qProcess))
         qProcess.error.connect(lambda: self.processCrashed(qProcess))
 
-        return qProcess.pid()
+        return getPid(qProcess)
 
     # recursive function used to run nmap in different stages for quick results
     def runStagedNmap(self, targetHosts, discovery = True, stage = 1, stop = False):
@@ -742,6 +775,8 @@ class Controller:
         if not stop:
             textbox = self.view.createNewTabForHost(str(targetHosts), 'nmap (stage ' + str(stage) + ')', True)
             outputfile = getNmapRunningFolder(runningFolder) + "/" + getTimestamp() + '-nmapstage' + str(stage)
+            if isWsl():
+                outputfile = unixPath2Win(outputfile)
 
             if stage == 1:
                 stageData = self.settings.tools_nmap_stage1_ports
@@ -758,32 +793,29 @@ class Controller:
             stageDataSplit = str(stageData).split('|')
             stageOp = stageDataSplit[0]
             stageOpValues = stageDataSplit[1]
+            log.debug("Stage {0} stageOp {1}".format(str(stage), str(stageOp)))
+            log.debug("Stage {0} stageOpValues {1}".format(str(stage), str(stageOpValues)))
 
-            command = "nmap "
-            if not discovery:                                           # is it with/without host discovery?
-                command += "-Pn "
-            command += "-T4 -sV "
+            if stageOp == "" or stageOp == "NOOP" or stageOp == "SKIP":
+                log.debug("Skipping stage {0} as stageOp is {1}".format(str(stage), str(stageOp)))
+                return
+
+            if discovery:                                           # is it with/without host discovery?
+                command = "nmap -T4 -sV -sSU -O "
+            else:
+                command = "nmap -Pn -sSU "
 
-            #if not stage == 1 and not stage == 3:
-            #    command += "-n "                                        # only do DNS resolution on first stage
-            #if os.geteuid() == 0:                                       # if we are root we can run SYN + UDP scans
-            #    command += "-sSU "
-            #    if stage == 2:
-            #        command += '-O '  # only check for OS once to save time and only if we are root otherwise it fail
-            #else:
-            #    command += '-sT '
-            
             if stageOp == 'PORTS':
-                command += '-p ' + stageOpValues + ' ' + targetHosts + ' -oA ' + outputfile
+                command += '-p ' + stageOpValues + ' -vvvv ' + targetHosts + ' -oA ' + outputfile
             elif stageOp == 'NSE':
                 command = 'nmap -sV --script=' + stageOpValues + ' -vvvv ' + targetHosts + ' -oA ' + outputfile
 
+            log.debug("Stage {0} command: {1}".format(str(stage), str(command)))
+
             self.runCommand('nmap', 'nmap (stage ' + str(stage) + ')', str(targetHosts), '', '', command,
                             getTimestamp(True), outputfile, textbox, discovery=discovery, stage=stage, stop=stop)
 
     def importFinished(self):
-        self.updateUI2Timer.stop()
-        self.updateUI2Timer.start(800)
         # if nmap import was the first action, we need to hide the overlay (note: we shouldn't need to do this
         # every time. this can be improved)
         self.view.displayAddHostsOverlay(False)
@@ -798,8 +830,8 @@ class Controller:
         imageviewer.setProperty('dbId', QVariant(str(dbId)))
         # to make sure the screenshot tab appears when it is launched from the host services tab
         self.view.switchTabClick()
-        self.updateUITimer.stop()  # update the processes table
-        self.updateUITimer.start(900)
+        #self.updateUITimer.stop()  # update the processes table
+        #self.updateUITimer.start(900)
 
     def processCrashed(self, proc):
         processRepository = self.logic.activeProject.repositoryContainer.processRepository
@@ -810,6 +842,8 @@ class Controller:
         self.view.findFinishedServiceTab(str(processRepository.getPIDByProcessId(str(proc.id))))
         log.info('Process {qProcessId} Output: {qProcessOutput}'.format(qProcessId=str(proc.id),
                                                                         qProcessOutput=qProcessOutput))
+        log.info('Process {qProcessId} Crash Output: {qProcessOutput}'.format(qProcessId=str(proc.id),
+                                                                              qProcessOutput=proc.errorString()))
 
     # this function handles everything after a process ends
     # def processFinished(self, qProcess, crashed=False):
@@ -818,14 +852,20 @@ class Controller:
         try:
             if not processRepository.isKilledProcess(
                     str(qProcess.id)):  # if process was not killed
+                log.debug('Process: {0}\nCommand: {1}\noutputfile: {2}'.format(str(qProcess.id), str(qProcess.command), str(qProcess.outputfile)))
                 if not qProcess.outputfile == '':
                     # move tool output from runningfolder to output folder if there was an output file
+                    outputfile = winPath2Unix(qProcess.outputfile)
                     self.logic.toolCoordinator.saveToolOutput(self.logic.activeProject.properties.outputFolder,
-                                                          qProcess.outputfile)
-                    print(qProcess.command)
+                                                          outputfile)
                     if 'nmap' in qProcess.command: # if the process was nmap, use the parser to store it
                         if qProcess.exitCode() == 0:                    # if the process finished successfully
-                            newoutputfile = qProcess.outputfile.replace(
+                            log.debug("qProcess.outputfile {0}".format(str(outputfile)))
+                            log.debug("self.logic.activeProject.properties.runningFolder {0}".format(
+                                str(self.logic.activeProject.properties.runningFolder)))
+                            log.debug("self.logic.activeProject.properties.outputFolder {0}".format(
+                                str(self.logic.activeProject.properties.outputFolder)))
+                            newoutputfile = outputfile.replace(
                                 self.logic.activeProject.properties.runningFolder,
                                 self.logic.activeProject.properties.outputFolder)
                             self.nmapImporter.setFilename(str(newoutputfile) + '.xml')
@@ -839,12 +879,6 @@ class Controller:
                             self.pythonImporter.setHostIp(str(qProcess.hostIp))
                             self.pythonImporter.setPythonScript(pythonScript)
                             self.pythonImporter.start()
-                exitCode = qProcess.exitCode()
-                if exitCode != 0 and exitCode != 255:
-                    log.info("Process {qProcessId} exited with code {qProcessExitCode}"
-                             .format(qProcessId=qProcess.id, qProcessExitCode=qProcess.exitCode()))
-                    self.processCrashed(qProcess)
-
                 log.info("Process {qProcessId} is done!".format(qProcessId=qProcess.id))
 
             processRepository.storeProcessOutput(str(qProcess.id), qProcess.display.toPlainText())
@@ -853,7 +887,7 @@ class Controller:
                 self.view.findFinishedBruteTab(str(processRepository.getPIDByProcessId(str(qProcess.id))))
 
             try:
-                self.fastProcessesRunning =- 1
+                self.fastProcessesRunning -= 1
                 self.checkProcessQueue()
                 self.processes.remove(qProcess)
                 self.updateUITimer.stop()
@@ -889,6 +923,13 @@ class Controller:
             log.info('-----------------------------------------------')
         log.info('Scheduler ended!')
 
+    def findDuplicateTab(self, tabWidget, tabName):
+        for i in range(tabWidget.count()):
+            log.debug("Tab text for {0}: {1}".format(str(i), str(tabWidget.tabText(i))))
+            if tabWidget.tabText(i) == tabName:
+                return True
+        return False
+
     def runToolsFor(self, service, hostname, ip, port, protocol='tcp'):
         log.info('Running tools for: ' + service + ' on ' + ip + ':' + port)
 
@@ -910,15 +951,18 @@ class Controller:
                     for a in self.settings.portActions:
                         if tool[0] == a[1]:
                             tabTitle = a[1] + " (" + port + "/" + protocol + ")"
+                            # Cheese
                             outputfile = self.logic.activeProject.properties.runningFolder + "/" + \
                                          re.sub("[^0-9a-zA-Z]", "", str(tool[0])) + \
                                          "/" + getTimestamp() + '-' + a[1] + "-" + ip + "-" + port
                             command = str(a[2])
                             command = command.replace('[IP]', ip).replace('[PORT]', port)\
-                                .replace('[OUTPUT]',
-                                                                                                  outputfile)
-                            log.debug("Running tool command " + str(command))
+                                .replace('[OUTPUT]', outputfile)
+                            log.debug("Running tool command: {0}".format(str(command)))
 
+                            if self.findDuplicateTab(self.view.ui.ServicesTabWidget, tabTitle):
+                                log.debug("Duplicate tab name. Tool might have already run.")
+                                break
                             tab = self.view.ui.HostsTabWidget.tabText(self.view.ui.HostsTabWidget.currentIndex())
                             self.runCommand(tool[0], tabTitle, ip, port, protocol, command,
                                             getTimestamp(True),
