@@ -1,6 +1,6 @@
 """
-LEGION (https://govanguard.com)
-Copyright (c) 2022 GoVanguard
+LEGION (https://gotham-security.com)
+Copyright (c) 2023 Gotham Security
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,8 +13,10 @@ Copyright (c) 2022 GoVanguard
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
+
+from sqlalchemy import text
 from db.SqliteDbAdapter import Database
 
 
@@ -23,8 +25,11 @@ class CVERepository:
         self.dbAdapter = dbAdapter
 
     def getCVEsByHostIP(self, hostIP):
-        query = ('SELECT cves.name, cves.severity, cves.product, cves.version, cves.url, cves.source, '
-                 'cves.exploitId, cves.exploit, cves.exploitUrl FROM cve AS cves '
-                 'INNER JOIN hostObj AS hosts ON hosts.id = cves.hostId '
-                 'WHERE hosts.ip = ?')
-        return self.dbAdapter.metadata.bind.execute(query, str(hostIP)).fetchall()
+        session = self.dbAdapter.session()
+        query = text('SELECT cves.name, cves.severity, cves.product, cves.version, cves.url, cves.source, '
+                     'cves.exploitId, cves.exploit, cves.exploitUrl FROM cve AS cves '
+                     'INNER JOIN hostObj AS hosts ON hosts.id = cves.hostId '
+                     'WHERE hosts.ip = :hostIP')
+        result = session.execute(query, {'hostIP': str(hostIP)}).fetchall()
+        session.close()
+        return result
