@@ -1,6 +1,6 @@
 """
-LEGION (https://govanguard.com)
-Copyright (c) 2022 GoVanguard
+LEGION (https://gotham-security.com)
+Copyright (c) 2023 Gotham Security
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2022 GoVanguard
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 from app.actions.updateProgress.AbstractUpdateProgressObserver import AbstractUpdateProgressObserver
 from ui.ancillaryDialog import ProgressWidget
@@ -29,6 +29,7 @@ class QtUpdateProgressObserver(AbstractUpdateProgressObserver):
     def onFinished(self) -> None:
         self.progressWidget.hide()
 
-    def onProgressUpdate(self, progress: int) -> None:
+    def onProgressUpdate(self, progress: int, title: str) -> None:
+        self.progressWidget.setText(title)
         self.progressWidget.setProgress(progress)
         self.progressWidget.show()
